#!/bin/bash

# SLURM configuration for MN5
#SBATCH --qos=gp_bsces
#SBATCH --output=serial_%j.out
#SBATCH --error=serial_%j.err
#SBATCH --ntasks=112
#SBATCH --time=012:00:00
#SBATCH --mail-type=end
#SBATCH --mail-user=amirpasha.mozaffari@bsc.es

# SLURM configuration for NORD3
##SBATCH --qos=bsc_es
##SBATCH --output=serial_%j.out
##SBATCH --error=serial_%j.err
##SBATCH --ntasks=10
##SBATCH --time=00:15:00
##SBATCH --mail-type=end
##SBATCH --mail-user=amirpasha.mozaffari@bsc.es
##SBATCH --constraint=highmem
##SBATCH --exclusive

# Load appropriate modules and activate conda environment
if [ "$BSC_MACHINE" = "mn5" ]; then

    export MODULEPATH=$MODULEPATH:/apps/GPP/EASYBUILD/modules/all
    module load GDAL/3.8.5-foss-2023b
    module load NCO/5.2.4-foss-2023b
    module load miniconda
    module load hdf5/1.14.1-2
    module load pnetcdf/1.12.3
    module load netcdf/2023-06-14
    module load miniconda
    conda init
    source /apps/GPP/MINICONDA/24.1.2/etc/profile.d/conda.sh
    conda activate /gpfs/projects/bsc32/repository/apps/conda_envs/LAND_may2024_v1
    export PYTHONPATH=/gpfs/projects/bsc32/repository/apps/conda_envs/LAND_may2024_v1/lib/python3.12/site-packages:$PYTHONPATH

elif [ "$BSC_MACHINE" = "nord3v2" ]; then
    module load GDAL/3.3.2-foss-2019b-Python-3.7.4
    module load pycdo/1.5.3-foss-2019b-Python-3.7.4
    module load pynco/0.0.2-foss-2019b-Python-3.7.4
fi

years=$(seq 1940 1941)
for year in ${years}; do
    echo "Processing year: ${year} "

    # Define variables
    input_nc="/gpfs/projects/bsc32/cerise/UMD/luh2_v2h/yearly/luh2_states_${year}.nc"
    output_dir="/gpfs/projects/bsc32/cerise/outputs/bsc032013/0.0089_deg/luh2class"
    resolution=0.0089
    output_width=40320
    output_height=20159
    xmin=-180.0044643
    ymin=-89.9955357
    xmax=179.9955357
    ymax=89.9955357

    # Call the script with arguments
    ./script-remap-luh2.sh "$input_nc" "$output_dir" "$resolution" "$output_width" "$output_height" "$xmin" "$ymin" "$xmax" "$ymax"

done 
echo "All years are processed"